==> tenant-security-token-domain-2.5.36-sources.jar: com/xforceplus/tenant/security/token/domain/TokenUser.java <==
package com.xforceplus.tenant.security.token.domain;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonView;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.xforceplus.tenant.security.token.domain.view.TokenView;
import io.geewit.core.jackson.view.View;
import io.swagger.annotations.ApiModelProperty;
import lombok.Setter;

import java.util.Set;

/**
 * @author geewit
 */
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonInclude(JsonInclude.Include.NON_NULL)
@Setter
public class TokenUser<R extends TokenRole> implements ITokenUser<R> {
    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("用户ID")
    protected Long id;

    @JsonView({TokenView.class})
    @ApiModelProperty("登录id")
    protected String loginId;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("当前租户ID")
    protected Long tenantId;

    @JsonView({View.class, TokenView.class})
    protected String tenantCode;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("租户名称")
    protected String tenantName;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("登录账号id")
    protected Long accountId;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("登录用户名")
    protected String username;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("手机")
    protected String mobile;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("邮箱")
    protected String email;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("用户名称")
    protected String userName;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("用户code")
    protected String userCode;

    @JsonView({TokenView.class})
    @ApiModelProperty("租户id集合")
    protected Set<Long> tenantIds;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("用户角色id集合")
    protected Set<R> roles;

    @JsonView({View.class, TokenView.MockView.class})
    @ApiModelProperty("资源码集合")
    protected Set<String> resourceCodes;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("模块名称")
    protected String modules;

    @Override
    public Set<Long> getTenantIds() {
        return tenantIds;
    }

    @JsonIgnore
    @ApiModelProperty("jwt token")
    protected String token;

    @JsonSerialize(using = ToStringSerializer.class)
    @Override
    public Long getId() {
        return id;
    }

    @Override
    public String getLoginId() {
        return loginId;
    }

    @JsonSerialize(using = ToStringSerializer.class)
    @Override
    public Long getTenantId() {
        return tenantId;
    }

    @Override
    public String getTenantCode() {
        return tenantCode;
    }

    @Override
    public String getTenantName() {
        return tenantName;
    }

    @JsonSerialize(using = ToStringSerializer.class)
    @Override
    public Long getAccountId() {
        return accountId;
    }

    @Override
    public String getUsername() {
        return username;
    }

    @Override
    public String getMobile() {
        return mobile;
    }

    @Override
    public String getEmail() {
        return email;
    }

    @Override
    public String getUserName() {
        return userName;
    }

    @Override
    public String getUserCode() {
        return userCode;
    }

    @Override
    public Set<R> getRoles() {
        return roles;
    }

    @Override
    public Set<String> getResourceCodes() {
        return resourceCodes;
    }

    @Override
    public String getModules() {
        return modules;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    @JsonView({TokenView.class})
    public String getLoginName() {
        return this.username;
    }

    public void setLoginName(String loginName) {

    }

    @JsonIgnore
    @Override
    public String token() {
        return token;
    }
}

==> tenant-security-token-domain-2.5.48-sources.jar: com/xforceplus/tenant/security/token/domain/TokenUser.java <==
package com.xforceplus.tenant.security.token.domain;

import com.fasterxml.jackson.annotation.*;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.xforceplus.tenant.security.token.domain.view.TokenView;
import io.geewit.core.jackson.view.View;
import io.swagger.annotations.ApiModelProperty;
import lombok.Setter;

import java.util.Set;

/**
 * @author geewit
 */
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonInclude(JsonInclude.Include.NON_NULL)
@Setter
public class TokenUser<R extends TokenRole> implements ITokenUser<R> {
    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("用户ID")
    protected Long id;

    @JsonView({TokenView.class})
    @ApiModelProperty("登录id")
    protected String loginId;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("当前租户ID")
    protected Long tenantId;

    @JsonView({View.class, TokenView.class})
    protected String tenantCode;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("租户名称")
    protected String tenantName;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("登录账号id")
    protected Long accountId;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("登录用户名")
    protected String username;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("手机")
    protected String mobile;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("邮箱")
    protected String email;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("用户名称")
    protected String userName;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("用户code")
    protected String userCode;

    @JsonView({TokenView.class})
    @ApiModelProperty("租户id集合")
    protected Set<Long> tenantIds;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("用户角色id集合")
    protected Set<R> roles;

    @JsonView({View.class, TokenView.MockView.class})
    @ApiModelProperty("资源码集合")
    protected Set<String> resourceCodes;

    @JsonView({View.class, TokenView.class})
    @ApiModelProperty("过滤组织code集合")
    protected String modules;

    @JsonView({View.class,TokenView.class})
    @ApiModelProperty("登录帐号")
    protected String loginName;

    @Override
    public Set<Long> getTenantIds() {
        return tenantIds;
    }

    @JsonIgnore
    @ApiModelProperty("jwt token")
    protected String token;

    @JsonSerialize(using = ToStringSerializer.class)
    @Override
    public Long getId() {
        return id;
    }

    @Override
    public String getLoginId() {
        return loginId;
    }

    @JsonSerialize(using = ToStringSerializer.class)
    @Override
    public Long getTenantId() {
        return tenantId;
    }

    @Override
    public String getTenantCode() {
        return tenantCode;
    }

    @Override
    public String getTenantName() {
        return tenantName;
    }

    @JsonSerialize(using = ToStringSerializer.class)
    @Override
    public Long getAccountId() {
        return accountId;
    }

    @Override
    public String getUsername() {
        return username;
    }

    @Override
    public String getMobile() {
        return mobile;
    }

    @Override
    public String getEmail() {
        return email;
    }

    @Override
    public String getUserName() {
        return userName;
    }

    @Override
    public String getUserCode() {
        return userCode;
    }

    @Override
    public Set<R> getRoles() {
        return roles;
    }

    @Override
    public Set<String> getResourceCodes() {
        return resourceCodes;
    }

    @Override
    public String getModules() {
        return modules;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    @JsonIgnore
    @Override
    public String token() {
        return token;
    }

    @Override
    public String getLoginName() {
        return loginName;
    }

    public void setLoginName(String loginName){
        this.loginName = loginName;
    }
}
